pub struct TrueAudioNextParameters {
pub baked_data_identifier: Option<BakedDataIdentifier>,
}Expand description
Multi-channel convolution reverb parameters, using AMD TrueAudio Next for GPU acceleration.
Fields
baked_data_identifier: Option<BakedDataIdentifier>The optional identifier used to specify which layer of baked data to use for simulating reflections for this source.